@@ -1,28 +1,13 @@
-# $File: /depot/local/PAR/trunk/lib/PAR/Packer.pm $ $Author: autrijus $
-# $Revision: #4 $ $Change: 11731 $ $DateTime: 2004-08-30T22:40:26.326020Z $ vim: expandtab shiftwidth=4
+# $File: //member/autrijus/PAR/lib/PAR/Packer.pm $ $Author: autrijus $
+# $Revision: #1 $ $Change: 10675 $ $DateTime: 2004/05/24 13:22:13 $ vim: expandtab shiftwidth=4
 
 package PAR::Packer;
-$PAR::Packer::VERSION = '0.12';
+$PAR::Packer::VERSION = '0.10';
 
 use 5.006;
 use strict;
 use warnings;
 
-=head1 NAME
-
-PAR::Packer - App::Packer backend for making PAR files
-
-=head1 DESCRIPTION
-
-This module implements the B<App::Packer::Backend> interface, for generating
-stand-alone executables, perl scripts and PAR files.
-
-Currently, this module is used by the command line tool B<pp> internally, as 
-well as by the contributed F<contrib/gui_pp/gpp> program.  Improvements on
-documenting the API will be most appreciated.
-
-=cut
-
 use Config;
 use Archive::Zip ();
 use Cwd ();
@@ -32,7 +17,6 @@ use File::Find ();
 use File::Spec ();
 use File::Temp ();
 use Module::ScanDeps ();
-use PAR ();
 use PAR::Filter ();
 
 use constant OPTIONS => {
@@ -70,7 +54,6 @@ use constant OPTIONS => {
 my $ValidOptions = {};
 my $LongToShort = { map { /^(\w+)\|(\w+)/ ? ($1, $2) : () } keys %{+OPTIONS} };
 my $ShortToLong = { reverse %$LongToShort };
-my $PerlExtensionRegex = qr/\.(?:al|ix|p(?:lx|l|h|m))\z/i;
 
 sub options { sort keys %{+OPTIONS} }
 
@@ -117,14 +100,15 @@ sub add_options {
 sub _translate_options {
     my ($self, $opt) = @_;
 
-    $self->_create_valid_hash($self->OPTIONS, $ValidOptions);
+    $self->_create_valid_hash(OPTIONS, $ValidOptions);
 
-    foreach my $key (keys(%$opt)) {
+    my $key;
+    foreach $key (keys(%$opt)) {
         my $value = $opt->{$key};
 
         if (!$ValidOptions->{$key}) {
-            $self->_warn("'$key' is not a valid option!\n");
-            $self->_show_usage;
+            warn "'$key' is not a valid option!\n";
+            usage();
         }
         else {
             $opt->{$key} = $value;
@@ -141,6 +125,8 @@ sub add_args {
 
 sub set_args {
     my ($self, @args) = @_;
+
+    unshift(@args, split ' ', $ENV{PP_OPTS}) if ($ENV{PP_OPTS});
     $self->{args} = \@args;
 }
 
@@ -154,20 +140,22 @@ sub set_front {
 sub _check_read {
     my ($self, @files) = @_;
 
+    my $sn = $self->{script_name};
     foreach my $file (@files) {
         unless (-r $file) {
-            $self->_die("Input file $file is a directory, not a file\n")
+            $self->_die("$sn: Input file $file is a directory, not a file\n")
               if (-d _);
             unless (-e _) {
-                $self->_die("Input file $file was not found\n");
+                $self->_die("$sn: Input file $file was not found\n");
             }
             else {
-                $self->_die("Cannot read input file $file: $!\n");
+                $self->_die("$sn: Cannot read input file $file: $!\n");
             }
         }
         unless (-f _) {
+
             # XXX: die?  don't try this on /dev/tty
-            $self->_warn("Input $file is not a plain file\n");
+            warn "$sn: WARNING: input $file is not a plain file\n";
         }
     }
 }
@@ -177,13 +165,13 @@ sub _check_write {
 
     foreach my $file (@files) {
         if (-d $file) {
-            $self->_die("Cannot write on $file, is a directory\n");
+            $self->_die("$0: Cannot write on $file, is a directory\n");
         }
         if (-e _) {
-            $self->_die("Cannot write on $file: $!\n") unless -w _;
+            $self->_die("$0: Cannot write on $file: $!\n") unless -w _;
         }
         unless (-w Cwd::cwd()) {
-            $self->_die("Cannot write in this directory: $!\n");
+            $self->_die("$0: Cannot write in this directory: $!\n");
         }
     }
 }
@@ -193,21 +181,20 @@ sub _check_perl {
     return if ($self->_check_par($file));
 
     unless (-T $file) {
-        $self->_warn("Binary '$file' sure doesn't smell like perl source!\n");
+        warn "$0: Binary `$file' sure doesn't smell like perl source!\n";
 
         if (my $file_checker = $self->_can_run("file")) {
-            $self->_vprint(0, "Checking file type... ");
+            print "Checking file type... ";
             system($file_checker, $file);
         }
         $self->_die("Please try a perlier file!\n");
     }
 
-    my $handle = $self->_open($file);
+    open(my $handle, "<", $file) or $self->_die("XXX: Can't open $file: $!");
 
-    local $/ = "\n";
-    local $_ = readline($handle);
-    if (/^#!/ and !/perl/) {
-        $self->_die("$file is a ", /^#!\s*(\S+)/, " script, not perl\n");
+    local $_ = <$handle>;
+    if (/^#!/ && !/perl/) {
+        $self->_die("$0: $file is a ", /^#!\s*(\S+)/, " script, not perl\n");
     }
 }
 
@@ -217,18 +204,20 @@ sub _sanity_check {
     my $input  = $self->{input};
     my $output = $self->{output};
 
+    my $sn = $self->{script_name};
+
     # Check the input and output files make sense, are read/writable.
     if ("@$input" eq $output) {
         my $a_out = $self->_a_out();
 
         if ("@$input" eq $a_out) {
-            $self->_die("Packing $a_out to itself is probably not what you want to do.\n");
+            $self->_die("$0: Packing $a_out to itself is probably not what you want to do.\n");
+
+           # You fully deserve what you get now. No you *don't*. typos happen.
         }
         else {
-            $self->_warn(
-                "Will not write output on top of input file, ",
-                "packing to $a_out instead\n"
-            );
+            warn "$sn: Will not write output on top of input file, ",
+              "packing to $a_out instead\n";
             $self->{output} = $a_out;
         }
     }
@@ -253,7 +242,11 @@ sub _parse_opts {
     my $opt  = $self->{options};
 
     $self->_verify_opts($opt);
-    $opt->{L} = (defined($opt->{L})) ? $opt->{L} : '';
+    $opt->{L} =
+        (defined($opt->{L})) ? $opt->{L}
+      : ($ENV{PAR_LOG}) ? $ENV{PAR_LOG}
+      : '';
+
     $opt->{p} = 1 if ($opt->{m});
     $opt->{v} = (defined($opt->{v})) ? ($opt->{v} || 1) : 0;
     $opt->{v} = 2 if ($opt->{vv});
@@ -263,12 +256,17 @@ sub _parse_opts {
     $self->{output}      = $opt->{o}            || $self->_a_out();
     $opt->{o}            = $opt->{o}            || $self->_a_out();
     $self->{script_name} = $self->{script_name} || $opt->{script_name} || $0;
+    my $sn = $self->{script_name};
 
-    $self->{logfh} = $self->_open('>>', $opt->{L})
-      if length $opt->{L};
+    my $lf;
+
+    open my $logfh, '>>', $opt->{L} or $self->_die("Cannot append to $opt->{L}$!")
+      if ($opt->{L});
+
+    $self->{logfh} = $logfh if ($logfh);
 
     if ($opt->{e}) {
-        $self->_warn("Using -e 'code' as input file, ignoring @$args\n")
+        warn "$sn: using -e 'code' as input file, ignoring @$args\n"
           if (@$args and !$opt->{r});
 
         my ($fh, $fake_input) =
@@ -282,6 +280,7 @@ sub _parse_opts {
         $self->{input} ||= [];
 
         push(@{ $self->{input} }, shift @$args) if (@$args);
+        my $sn = $self->{script_name};
 
         push(@{ $self->{input} }, @$args) if (@$args and !$opt->{r});
         my $in = $self->{input};
@@ -295,16 +294,17 @@ sub _parse_opts {
 sub _verify_opts {
     my ($self, $opt) = @_;
 
-    $self->_create_valid_hash($self->OPTIONS, $ValidOptions);
+    $self->_create_valid_hash(OPTIONS, $ValidOptions);
 
     my $show_usage = 0;
-    foreach my $key (keys(%$opt)) {
+    my $key;
+    foreach $key (keys(%$opt)) {
         if (!$ValidOptions->{$key}) {
-            $self->_warn("'$key' is not a valid option!\n");
+            warn "'$key' is not a valid option!\n";
             $show_usage = 1;
+
         }
     }
-
     $self->_show_usage() if ($show_usage);
 }
 
@@ -313,7 +313,8 @@ sub _create_valid_hash {
 
     return () if (%$hashout);
 
-    foreach my $key (keys(%$hashin)) {
+    my $key;
+    foreach $key (keys(%$hashin)) {
         my (@keys) = ($key =~ /\|/) ? ($key =~ /(?<!:)(\w+)/g) : ($key);
         @{$hashout}{@keys} = ($hashin->{$key}) x @keys;
     }
@@ -346,13 +347,21 @@ sub go {
 sub _setup_run {
     my ($self) = @_;
 
-    my $opt    = $self->{options};
-    my $args   = $self->{args};
+    my $opt  = $self->{options};
+    my $sn   = $self->{script_name};
+    my $args = $self->{args};
+
+    $self->_die("$sn: No input files specified\n")
+      unless @{ $self->{input} }
+      or $opt->{M};
+
+    unless (eval { require PAR; 1 }) {
+        $self->{parl} ||= $self->_can_run("parl$Config{_exe}")
+          or die("Can't find par loader");
+        exec($self->{parl}, $sn, @$args);
+    }
+
     my $output = $self->{output};
-
-    $self->_die("No input files specified\n")
-      unless @{ $self->{input} } or $opt->{M};
-
     $self->_check_write($output);
 }
 
@@ -369,6 +378,7 @@ sub generate_pack {
     $self->_vprint(0, "Packing @$input");
 
     if ($self->_check_par($input->[0])) {
+
         # invoked as "pp foo.par" - never unlink it
         $self->{par_file} = $input->[0];
         $opt->{S}         = 1;
@@ -497,7 +507,11 @@ sub _add_add_manifest {
 sub _make_manifest {
     my ($self) = @_;
 
+    my $input = $self->{input};
+
     my $full_manifest = $self->{full_manifest};
+    my $dep_manifest  = $self->{dep_manifest};
+    my $add_manifest  = $self->{add_manifest};
 
     my $opt      = $self->{options};
     my $par_file = $self->{par_file};
@@ -529,22 +543,16 @@ par:
   version: $PAR::VERSION
 YAML
 
-    $self->_vprint(2, "... updating $_") for qw(MANIFEST META.yml);
+    $self->_vprint(2, "... making $_") for qw(MANIFEST META.yml);
 
-    my $zip = $self->{zip};
+    my %manifest = map { $_ => 1 } ('MANIFEST', 'META.yml');
+
+    $full_manifest->{'MANIFEST'} = [ 'string', $manifest ];
+    $full_manifest->{'META.yml'} = [ 'string', $meta_yaml ];
+
+    $dep_manifest->{'MANIFEST'} = [ 'string', $manifest ];
+    $dep_manifest->{'META.yml'} = [ 'string', $meta_yaml ];
 
-    $zip->removeMember( 'MANIFEST' );
-    $zip->addString(
-        $manifest => 'MANIFEST',
-        desiredCompressionMethod => Archive::Zip::COMPRESSION_DEFLATED(),
-        desiredCompressionLevel  => Archive::Zip::COMPRESSION_LEVEL_BEST_COMPRESSION(),
-    );
-    $zip->removeMember( 'META.yml' );
-    $zip->addString(
-        $meta_yaml => 'META.yml',
-        desiredCompressionMethod => Archive::Zip::COMPRESSION_DEFLATED(),
-        desiredCompressionLevel  => Archive::Zip::COMPRESSION_LEVEL_BEST_COMPRESSION(),
-    );
 }
 
 sub get_par_file {
@@ -560,9 +568,9 @@ sub get_par_file {
 
     my $opt = $self->{options};
 
-    if ($opt->{S} or $opt->{p}) {
-        # We need to keep it.
+    if ($opt->{S} || $opt->{p}) {
 
+        # We need to keep it.
         if ($opt->{e} or !@$input) {
             $par_file = "a.par";
         }
@@ -570,16 +578,20 @@ sub get_par_file {
             $par_file = $input->[0];
 
             # File off extension if present
-            $par_file =~ s/$PerlExtensionRegex//;
+            # hold on: plx is executable; also, careful of ordering!
+
+            $par_file =~ s/\.(?:p(?:lx|l|h)|m)\z//i;
             $par_file .= ".par";
         }
 
-        $par_file = $output if $opt->{p} and $output =~ /\.par\z/i;
+        $par_file = $output if ($opt->{p} && $output =~ /\.par\z/i);
+
         $output = $par_file if $opt->{p};
 
         $self->_check_write($par_file);
     }
     else {
+
         # Don't need to keep it, be safe with a tempfile.
 
         $self->{pack_attrib}{lose} = 1;
@@ -651,8 +663,9 @@ sub pack_manifest_hash {
         execute => $opt->{x},
         compile => $opt->{c},
         skip    => \%skip,
-        ($opt->{n}) ? () : (
-            recurse => 1,
+        ($opt->{n})
+        ? ()
+        : (        recurse => 1,
             first   => 1,
         ),
     );
@@ -684,9 +697,9 @@ sub pack_manifest_hash {
         $tmpzip->read($par_file);
 
         if ($old_member = $tmpzip->memberNamed('MANIFEST')) {
-            $full_manifest->{$_} = [ file => $_ ]
+            $full_manifest->{$_} = [ "file", $_ ]
               for (grep /^\S/, split(/\n/, $old_member->contents));
-            $dep_manifest->{$_} = [ file => $_ ]
+            $dep_manifest->{$_} = [ "file", $_ ]
               for (grep /^\S/, split(/\n/, $old_member->contents));
         }
         else {
@@ -703,10 +716,9 @@ sub pack_manifest_hash {
       );
 
     foreach my $pfile (sort grep length $map{$_}, keys %map) {
-        next if !$opt->{B} and (
-            ($map{$pfile} eq "$Config{privlib}/$pfile") or
-            ($map{$pfile} eq "$Config{archlib}/$pfile")
-        );
+        next
+          if (!$opt->{B} and ($map{$pfile} eq "$Config{privlib}/$pfile")
+            or $map{$pfile} eq "$Config{archlib}/$pfile");
 
         $self->_vprint(2, "... adding $map{$pfile} as ${root}lib/$pfile");
 
@@ -714,30 +726,30 @@ sub pack_manifest_hash {
             my $content_ref = $mod_filter->apply($map{$pfile}, $pfile);
 
             $full_manifest->{ $root . "lib/$pfile" } =
-              [ string => $content_ref ];
+              [ "string", $content_ref ];
             $dep_manifest->{ $root . "lib/$pfile" } =
-              [ string => $content_ref ];
+              [ 'string', $content_ref ];
         }
         elsif (
             File::Basename::basename($map{$pfile}) =~ /^Tk\.dll$/i and $opt->{i}
             and eval { require Win32::Exe; 1 }
             and eval { require Win32::Exe::IconFile; 1 }
-            and 0 # XXX - broken on larger icon files - XXX
+            and $] < 5.008 # XXX - broken on ActivePerl 5.8+ 
         ) {
             my $tkdll = Win32::Exe->new($map{$pfile});
             my $ico = Win32::Exe::IconFile->new($opt->{i});
             $tkdll->set_icons(scalar $ico->icons);
 
             $full_manifest->{ $root . "lib/$pfile" } =
-              [ string => $tkdll->dump ];
+              [ "string", $tkdll->dump ];
             $dep_manifest->{ $root . "lib/$pfile" } =
-              [ string => $tkdll->dump ];
+              [ 'string', $tkdll->dump ];
         }
         else {
             $full_manifest->{ $root . "lib/$pfile" } =
-              [ file => $map{$pfile} ];
+              [ "file", $map{$pfile} ];
             $dep_manifest->{ $root . "lib/$pfile" } =
-              [ file => $map{$pfile} ];
+              [ "file", $map{$pfile} ];
         }
     }
 
@@ -749,14 +761,14 @@ sub pack_manifest_hash {
         my $name = File::Basename::basename($in);
 
         if ($script_filter) {
-            my $string = $script_filter->apply($in, $name);
+            my $string = $script_filter->appliy($in, $name);
 
-            $full_manifest->{"script/$name"} = [ string => $string ];
-            $dep_manifest->{"script/$name"}  = [ string => $string ];
+            $full_manifest->{"script/$name"} = [ "string", $string ];
+            $dep_manifest->{"script/$name"}  = [ "string", $string ];
         }
         else {
-            $full_manifest->{"script/$name"} = [ file => $in ];
-            $dep_manifest->{"script/$name"}  = [ file => $in ];
+            $full_manifest->{"script/$name"} = [ "file", $in ];
+            $dep_manifest->{"script/$name"}  = [ "file", $in ];
         }
     }
 
@@ -766,17 +778,17 @@ sub pack_manifest_hash {
         next unless -e $in;
         my $name = File::Basename::basename($in);
 
-        $dep_manifest->{"$shlib/$name"}  = [ file => $in ];
-        $full_manifest->{"$shlib/$name"} = [ file => $in ];
+        $dep_manifest->{"$shlib/$name"}  = [ "file", $in ];
+        $full_manifest->{"$shlib/$name"} = [ "file", $in ];
     }
 
     foreach my $in (@data) {
         unless (-r $in and !-d $in) {
-            $self->_warn("'$in' does not exist or is not readable; skipping\n");
+            warn "'$in' does not exist or is not readable; skipping\n";
             next;
         }
-        $full_manifest->{$in} = [ file => $in ];
-        $dep_manifest->{$in} = [ file => $in ];
+        $full_manifest->{$in} = [ "file", $in ];
+        $dep_manifest->{$in} = [ "file", $in ];
     }
 
     if (@$input and (@$input == 1 or !$opt->{p})) {
@@ -785,15 +797,15 @@ sub pack_manifest_hash {
           ? $self->_main_pl_single("script/" . File::Basename::basename($input->[0]))
           : $self->_main_pl_multi();
 
-        $full_manifest->{"script/main.pl"} = [ string => $string ];
-        $dep_manifest->{"script/main.pl"}  = [ string => $string ];
+        $full_manifest->{"script/main.pl"} = [ 'string', $string ];
+        $dep_manifest->{"script/main.pl"}  = [ 'string', $string ];
     }
 
-    $full_manifest->{'MANIFEST'} = [ string => "<<placeholder>>" ];
-    $full_manifest->{'META.yml'} = [ string => "<<placeholder>>" ];
+    $full_manifest->{'MANIFEST'} = [ 'string', "<<placeholder>>" ];
+    $full_manifest->{'META.yml'} = [ 'string', "<<placeholder>>" ];
 
-    $dep_manifest->{'MANIFEST'} = [ string => "<<placeholder>>" ];
-    $dep_manifest->{'META.yml'} = [ string => "<<placeholder>>" ];
+    $dep_manifest->{'MANIFEST'} = [ 'string', "<<placeholder>>" ];
+    $dep_manifest->{'META.yml'} = [ 'string', "<<placeholder>>" ];
 
     return ($dep_manifest);
 }
@@ -823,23 +835,17 @@ sub add_manifest_hash {
     my $elt;
 
     foreach $elt (@$ma) {
-        my ($file, $alias) = @$elt;
+        if (-f $elt->[0]) {
+            $mh->{ $elt->[1] } = [ 'file', $elt->[0] ];
+        }
+        elsif (-d $elt->[0]) {
+            my ($f, $a) = $self->_expand_dir(@$elt);
 
-        if (!-e $file) {
-            $self->_warn("Cannot find file or directory $file for packing\n");
-        }
-        elsif (!-r _) {
-            $self->_warn("Cannot read file or directory $file for packing\n");
-        }
-        elsif (-d _) {
-            my ($files, $aliases) = $self->_expand_dir(@$elt);
-            while (@$files) {
-                $mh->{ shift(@$aliases) } = [ file => shift(@$files) ];
+            my $xx;
+            for ($xx = 0 ; $xx < @$f ; $xx++) {
+                $mh->{ $a->[$xx] } = [ 'file', $f->[$xx] ];
             }
         }
-        else {
-            $mh->{ $alias } = [ file => $file ];
-        }
     }
     return ($mh);
 }
@@ -855,26 +861,18 @@ sub _add_manifest {
     $files = $opt->{a} if ($opt->{a});
     $lists = $opt->{A} if ($opt->{A});
 
-    local $/ = "\n";
     foreach my $list (@$lists) {
-        my $fh = $self->_open('<', $list, 'text');
-        while (my $line = <$fh>) {
-            chomp($line);
-            push(@$files, $line);
-        }
+        open my $fh, $list or $self->_die("Can't open file $list: $!\n");
+        while (my $line = <$fh>) { chomp($line); push(@$files, $line); }
     }
 
     foreach my $file (grep length, @$files) {
-        $file =~ s{\\}{/}g;
-
         if ($file =~ /;/) {
-            push(@$return, [ split(/;/, $file) ]);
+            my @split = split(/;+/, $file);
+            push(@$return, [ @split[0, 1] ]);
         }
         else {
-            my $alias = $file;
-            $alias =~ s{^[a-zA-Z]:}{} if $^O eq 'MSWin32';
-            $alias =~ s{^/}{};
-            push(@$return, [ $file, $alias ]);
+            push(@$return, [ $file, $file ]);
         }
     }
     return ($return);
@@ -905,7 +903,7 @@ sub _add_pack_manifest {
 
     my $pack_manifest = $self->pack_manifest_hash();
 
-    my $map         = $self->{pack_attrib}{map};
+    my $map         = $self->{pack_attrib}{'map'};
     my $root        = $self->{pack_attrib}{root};
     my $shared_libs = $self->{pack_attrib}{shared_libs};
 
@@ -943,7 +941,8 @@ sub _add_file {
     my $oldsize       = $self->{pack_attrib}{old_size};
     my $full_manifest = $self->{full_manifest};
 
-    if ($value->[0] eq 'file') {
+    if ($value->[0] eq "file")    # file
+    {
         my $fn = $value->[1];
 
         if (-d $fn) {
@@ -951,20 +950,20 @@ sub _add_file {
 
             $self->_vprint(1, "... adding $fn as $in\n");
 
-            while (@$files) {
-                my $file  = shift @$files;
-                my $alias = shift @$aliases;
+            my $xx;
+            for ($xx = 0 ; $xx < @$files ; $xx++) {
+                $self->_vprint(1, "... adding $fn as $in\n");
 
-                $self->_vprint(1, "... adding $file as $alias\n");
+                $full_manifest->{ $aliases->[$xx] } =
+                  [ 'file', $files->[$xx] ];
+                $manifest->{ $aliases->[$xx] } = [ 'file', $files->[$xx] ];
 
-                $full_manifest->{ $alias } = [ file => $file ];
-                $manifest->{ $alias } = [ file => $file ];
-
-                $oldsize += -s $file;
-                $zip->addFile($file, $alias);
+                $oldsize += -s $files->[$xx];
+                $zip->addFile($files->[$xx], $aliases->[$xx]);
             }
         }
-        elsif (-e $fn and -r $fn) {
+        else {
+
             $self->_vprint(1, "... adding $fn as $in\n");
 
             $oldsize += -s $fn;
@@ -977,7 +976,7 @@ sub _add_file {
 
         $self->_vprint(1, "... adding <string> as $in");
         $zip->addString(
-            $str => $in,
+            $str => $in, 
             desiredCompressionMethod => Archive::Zip::COMPRESSION_DEFLATED(),
             desiredCompressionLevel  => Archive::Zip::COMPRESSION_LEVEL_BEST_COMPRESSION(),
         );
@@ -993,7 +992,7 @@ sub _expand_dir {
     File::Find::find(
         {
             wanted => sub { push(@return, $File::Find::name) if -f },
-            follow_fast => ( ($^O eq 'MSWin32') ? 0 : 1 ),
+            follow_fast => 1
         },
         $fn
     );
@@ -1006,28 +1005,12 @@ sub _expand_dir {
 
 sub _die {
     my ($self, @args) = @_;
-    $self->_log(@args);
-
-    my $sn = $self->{script_name};
-    die "$sn: ", @args;
-}
-
-sub _warn {
-    my ($self, @args) = @_;
-    $self->_log(@args);
-
-    my $sn = $self->{script_name};
-    warn "$sn: ", @args;
-}
-
-sub _log {
-    my ($self, @args) = @_;
 
     my $opt   = $self->{options};
     my $logfh = $self->{logfh};
-    my $sn    = $self->{script_name};
 
-    $logfh->print("$sn: ", @args) if ($opt->{L});
+    $logfh->print(@args) if ($opt->{L});
+    die @args;
 }
 
 sub _name2moddata {
@@ -1037,14 +1020,10 @@ sub _name2moddata {
         $name =~ s/::/\//g;
         push @$mod, "$name.pm";
     }
-    elsif ($name =~ /$PerlExtensionRegex/) {
+    elsif ($name =~ /\.(?:pm|ix|al|pl)$/i) {
         push @$mod, $name;
     }
     else {
-        $self->_warn(
-            "Using -M to add non-library files is deprecated; ",
-            "try -a instead",
-        );
         push @$dat, $name;
     }
 }
@@ -1064,8 +1043,7 @@ sub _par_to_exe {
     $parl .= $Config{_exe};
 
     $parl = 'par.pl' if ($opt->{P});
-    $self->{parl} = $self->_can_run($parl, $opt->{P})
-      or $self->_die("Can't find par loader");
+    $self->{parl} = $self->_can_run($parl, $opt->{P}) or $self->_die("Can't find par loader");
 
     if ($^O ne 'MSWin32' or $opt->{p} or $opt->{P}) {
         $self->_generate_output();
@@ -1095,7 +1073,7 @@ sub _par_to_exe {
         return;
     }
     else {
-	$self->_die("--icon and --info support needs Win32::Exe");
+	die "--icon and --info support needs Win32::Exe";
     }
 }
 
@@ -1114,15 +1092,15 @@ sub _fix_console {
     if ($dynperl and !$opt->{d}) {
         # we have a static.exe that needs taking care of.
         my $buf;
-        my $fh = $self->_open($self->{orig_parl} || $self->{parl});
-        seek $fh, -8, 2;
-        read $fh, $buf, 8;
+        open _FH, $self->{orig_parl} || $self->{parl} or die $!;
+        binmode _FH;
+        seek _FH, -8, 2;
+        read _FH, $buf, 8;
         die unless $buf eq "\nPAR.pm\n";
-        seek $fh, -12, 2;
-        read $fh, $buf, 4;
-        seek $fh, -12 - unpack("N", $buf) - 4, 2;
-        read $fh, $buf, 4;
-        close $fh;
+        seek _FH, -12, 2;
+        read _FH, $buf, 4;
+        seek _FH, -12 - unpack("N", $buf) - 4, 2;
+        read _FH, $buf, 4;
         $self->_strip_console($output, unpack("N", $buf));
     }
 }
@@ -1133,37 +1111,28 @@ sub _move_parl {
     $self->{orig_parl} = $self->{parl};
 
     my $cfh;
-    my $fh = $self->_open($self->{parl});
-    ($cfh, $self->{parl}) = File::Temp::tempfile(
-        "parlXXXX",
-        SUFFIX => ".exe",
-        UNLINK => 1,
-    );
-    binmode($cfh);
-
     local $/;
-    print $cfh readline($fh);
+    open _FH, $self->{parl} or die $!;
+    binmode(_FH);
+    ($cfh, $self->{parl}) = File::Temp::tempfile("parlXXXX", SUFFIX => ".exe", UNLINK => 1);
+    binmode($cfh);
+    print $cfh <_FH>;
     close $cfh;
-
-    $self->{fh} = $fh;
 }
 
 sub _append_parl {
     my ($self) = @_;
 
-    my $fh = delete $self->{fh};
-
     my $buf;
-    seek $fh, -8, 2;
-    read $fh, $buf, 8;
+    seek _FH, -8, 2;
+    read _FH, $buf, 8;
     die unless $buf eq "\nPAR.pm\n";
-    seek $fh, -12, 2;
-    read $fh, $buf, 4;
-    seek $fh, -12 - unpack("N", $buf), 2;
-
-    local $/;
-    my $cfh = $self->_open('>>', $self->{parl});
-    print $cfh readline($fh);
+    seek _FH, -12, 2;
+    read _FH, $buf, 4;
+    seek _FH, -12 - unpack("N", $buf), 2;
+    open my $cfh, ">>", $self->{parl} or die $!;
+    binmode($cfh);
+    print $cfh <_FH>;
     close $cfh;
 }
 
@@ -1175,7 +1144,7 @@ sub _generate_output {
     my $par_file = $self->{par_file};
 
     my @args = ('-B', "-O$output", $par_file);
-    unshift @args, '-q' unless $opt->{v} > 0;
+    unshift @args, '-q' unless $opt->{v};
     if ($opt->{L}) {
         unshift @args, "-L".$opt->{L};
     }
@@ -1194,7 +1163,7 @@ sub _strip_console {
 
     my ($record, $magic, $signature, $offset, $size);
 
-    my $exe = $self->_open('+<', $file);
+    open my $exe, "+< $file" or die "Cannot open $file: $!\n";
     binmode $exe;
     seek $exe, $preoff, 0;
 
@@ -1235,7 +1204,8 @@ sub _obj_function {
 
         if (%$module_or_class) {
             # hack because Module::ScanDeps isn't really object.
-            return sub { $func->($module_or_class, @_) };
+            my $closure = sub { &$func($module_or_class, @_) };
+            return ($closure);
         }
         else {
             return ($func);
@@ -1257,21 +1227,19 @@ sub _vprint {
 
     my $verb = $ENV{PAR_VERBOSE} || 0;
     if ($opt->{v} > $level or $verb > $level) {
-        if ($opt->{L}) {
-            print $logfh "$0: $msg";
-        }
-        else {
-            print "$0: $msg";
-        }
+        print "$0: $msg"        if (!$opt->{L});
+        print $logfh "$0: $msg" if ($opt->{L});
     }
 }
 
 sub _check_par {
     my ($self, $file) = @_;
 
+    open(my $handle, "<", $file) or $self->_die("XXX: Can't open $file: $!");
+
+    binmode($handle);
     local $/ = \4;
-    my $handle = $self->_open($file);
-    return (readline($handle) eq "PK\x03\x04");
+    return (<$handle> eq "PK\x03\x04");
 }
 
 sub _find_shlib {
@@ -1311,7 +1279,6 @@ sub _can_run {
 }
 
 sub _main_pl_multi {
-    my ($self) = @_;
     return << '__MAIN__';
 my $file = $ENV{PAR_PROGNAME};
 my $zip = $PAR::LibCache{$ENV{PAR_PROGNAME}} || Archive::Zip->new(__FILE__);
@@ -1327,18 +1294,6 @@ PAR::_run_member($member, 1);
 __MAIN__
 }
 
-sub _open {
-    my ($self, $mode, $file, $is_text) = @_;
-    ($mode, $file) = ('<', $mode) if @_ < 3;
-    open(my $fh, $mode, $file) or $self->_die(
-        "Cannot open $file for ",
-        (($mode =~ '>') ? 'writing' : 'reading'),
-        ": $!",
-    );
-    binmode($fh) unless $is_text;
-    return $fh;
-}
-
 sub _main_pl_single {
     my ($self, $file) = @_;
     return << "__MAIN__";
@@ -1356,40 +1311,7 @@ sub DESTROY {
     my $par_file = $self->{par_file};
     my $opt      = $self->{options};
 
-    unlink $par_file if ($par_file and !$opt->{S} and !$opt->{p});
+    unlink $par_file if ($par_file && !$opt->{S} && !$opt->{p});
 }
 
 1;
-
-=head1 SEE ALSO
-
-L<PAR>, L<pp>
-
-L<App::Packer>, L<App::Packer::Backend>
-
-=head1 ACKNOWLEDGMENTS
-
-Mattia Barbon for taking the first step in refactoring B<pp> into
-B<App::Packer::Backend::PAR>, and Edward S. Peschko for continuing
-the work that eventually became this module.
-
-=head1 AUTHORS
-
-Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
-
-L<http://par.perl.org/> is the official PAR website.  You can write
-to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
-E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
-
-Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
-
-=head1 COPYRIGHT
-
-Copyright 2004 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
